typed_descriptors.base
======================

.. automodule:: typed_descriptors.base

DescriptorBase
--------------

.. autoclass:: typed_descriptors.base.DescriptorBase
    :show-inheritance:
    :members:
    :special-members: __init__, __set_name__, __get__

T
-

.. autodata:: typed_descriptors.base.T

T_co
----

.. autodata:: typed_descriptors.base.T_co

TypedDescriptor
---------------

.. autoclass:: typed_descriptors.base.TypedDescriptor
    :show-inheritance:
    :members:
    :special-members: __descriptor_type__, __set_name__, __get__

class_slots
-----------

.. autofunction:: typed_descriptors.base.class_slots

is_dict_available
-----------------

.. autofunction:: typed_descriptors.base.is_dict_available

name_mangle
-----------

.. autofunction:: typed_descriptors.base.name_mangle

name_unmangle
-------------

.. autofunction:: typed_descriptors.base.name_unmangle
